@@ -1,10 +1,20 @@
 # vim: filetype=ruby:expandtab:shiftwidth=2:tabstop=8:softtabstop=2 :
 
 if /mingw|mswin|mswin32/ =~ RUBY_PLATFORM
-  require 'rbconfig'
-  ENV['PATH'] = %w(bin lib).collect do |dir|
-    "#{Config::CONFIG["prefix"]}\\lib\\GTK\\#{dir};"
-  end.join('') + ENV['PATH']
+  require 'pathname'
+  base_dir = Pathname(File.dirname(__FILE__))
+  base_dir = base_dir.parent.parent + "cairo"
+  if base_dir.exist?
+    base_dir = base_dir.to_s.gsub(/\//, "\\")
+    ENV['PATH'] = %w(bin lib).collect do |dir|
+      "#{base_dir}\\#{dir};"
+    end.join('') + ENV['PATH']
+  else
+    require 'rbconfig'
+    ENV['PATH'] = %w(bin lib).collect do |dir|
+      "#{Config::CONFIG["prefix"]}\\lib\\GTK\\#{dir};"
+    end.join('') + ENV['PATH']
+  end
 end
 
 module Cairo
@@ -27,6 +37,7 @@ module Cairo
 end
 
 require 'cairo/color'
+require 'cairo/paper'
 
 require 'cairo.so'
 require 'cairo/constants'
@@ -53,11 +64,39 @@ module Cairo
     end
   end
 
-  class SVGSurface
-    class << self
-      def versions_as_string
-        versions.collect do |version|
-          version_to_string(version)
+  if const_defined?("PSLevel")
+    module PSLevel
+      class << self
+        def names
+          list.collect {|version| name(version)}
+        end
+      end
+    end
+  end
+
+  if const_defined?("SVGVersion")
+    module SVGVersion
+      class << self
+        def names
+          list.collect {|version| name(version)}
+        end
+      end
+    end
+  end
+
+  if const_defined?("SVGSurface")
+    class SVGSurface
+      class << self
+        def versions_as_string
+          SVGVersion.names
+        end
+
+        def versions
+          SVGVersion.list
+        end
+
+        def version_to_string(version)
+          SVGVersion.name(version)
         end
       end
     end
@@ -91,6 +130,7 @@ end
 
 require 'cairo/point'
 require 'cairo/colors'
+require 'cairo/papers'
 require 'cairo/context'
 require 'cairo/path'
 
