@@ -3,7 +3,7 @@
  * Ruby Cairo Binding
  *
  * $Author: kou $
- * $Date: 2007-05-27 02:46:01 $
+ * $Date: 2008-07-19 11:00:10 $
  *
  * Copyright 2006-2007 Kouhei Sutou <kou@cozmixng.org>
  * Copyright 2005 Øyvind Kolås <pippin@freedesktop.org>
@@ -17,7 +17,7 @@
 #include "rb_cairo.h"
 #include "rb_cairo_private.h"
 
-VALUE rb_mCairo, rb_mCairo_Color, rb_cCairo_Color_Base;
+VALUE rb_mCairo, rb_mCairo_Color, rb_cCairo_Color_Base, rb_cCairo_Paper;
 
 static ID id__add_one_arg_setter;
 
@@ -58,10 +58,11 @@ Init_cairo ()
 
   rb_define_const (rb_mCairo, "BINDINGS_VERSION",
                    rb_ary_new3 (4,
-                                INT2FIX (1), INT2FIX (5), INT2FIX (1), Qnil));
+                                INT2FIX (1), INT2FIX (6), INT2FIX (3), Qnil));
 
   rb_mCairo_Color = rb_const_get (rb_mCairo, rb_intern ("Color"));
   rb_cCairo_Color_Base = rb_const_get (rb_mCairo_Color, rb_intern ("Base"));
+  rb_cCairo_Paper = rb_const_get (rb_mCairo, rb_intern ("Paper"));
 
   Init_cairo_private ();
   Init_cairo_constants ();
