@@ -3,7 +3,7 @@
  * Ruby Cairo Binding
  *
  * $Author: kou $
- * $Date: 2008-01-11 12:18:34 $
+ * $Date: 2008-06-19 13:00:18 $
  *
  * Copyright 2005 Øyvind Kolås <pippin@freedesktop.org>
  * Copyright 2004-2005 MenTaLguY <mental@rydia.com>
@@ -18,28 +18,18 @@
 
 #include <cairo.h>
 
-#if CAIRO_HAS_PS_SURFACE
+#ifdef CAIRO_HAS_PS_SURFACE
 #  include <cairo-ps.h>
 #endif
 
-#if CAIRO_HAS_PDF_SURFACE
+#ifdef CAIRO_HAS_PDF_SURFACE
 #  include <cairo-pdf.h>
 #endif
 
-#if CAIRO_HAS_SVG_SURFACE
+#ifdef CAIRO_HAS_SVG_SURFACE
 #  include <cairo-svg.h>
 #endif
 
-#if CAIRO_HAS_WIN32_SURFACE
-#  define OpenFile OpenFile_win32
-#  include <cairo-win32.h>
-#  undef OpenFile
-#endif
-
-#if CAIRO_HAS_QUARTZ_SURFACE
-#  include <cairo-quartz.h>
-#endif
-
 #define CAIRO_CHECK_VERSION(major, minor, micro)    \
     (CAIRO_VERSION_MAJOR > (major) || \
      (CAIRO_VERSION_MAJOR == (major) && CAIRO_VERSION_MINOR > (minor)) || \
@@ -104,9 +94,11 @@ RB_CAIRO_VAR VALUE rb_cCairo_PDFSurface;
 RB_CAIRO_VAR VALUE rb_cCairo_PSSurface;
 RB_CAIRO_VAR VALUE rb_cCairo_SVGSurface;
 RB_CAIRO_VAR VALUE rb_cCairo_Win32Surface;
+RB_CAIRO_VAR VALUE rb_cCairo_Win32PrintingSurface;
 /* For backward compatibility*/
 #define rb_cCairo_WIN32Surface rb_cCairo_Win32Surface
 RB_CAIRO_VAR VALUE rb_cCairo_QuartzSurface;
+RB_CAIRO_VAR VALUE rb_cCairo_QuartzImageSurface;
 
 RB_CAIRO_VAR VALUE rb_mCairo_Operator;
 RB_CAIRO_VAR VALUE rb_mCairo_Antialias;
@@ -129,6 +121,7 @@ RB_CAIRO_VAR VALUE rb_mCairo_Filter;
 RB_CAIRO_VAR VALUE rb_mCairo_SVGVersion;
 RB_CAIRO_VAR VALUE rb_mCairo_Color;
 RB_CAIRO_VAR VALUE rb_cCairo_Color_Base;
+RB_CAIRO_VAR VALUE rb_cCairo_Paper;
 
 
 #define RVAL2CRCONTEXT(obj)     (rb_cairo_context_from_ruby_object(obj))
@@ -163,6 +156,8 @@ RB_CAIRO_VAR VALUE rb_cCairo_Color_Base;
 
 #define RVAL2CRSURFACE(obj)     (rb_cairo_surface_from_ruby_object(obj))
 #define CRSURFACE2RVAL(surface) (rb_cairo_surface_to_ruby_object(surface))
+#define CRSURFACE2RVAL_WITH_DESTROY(surface) \
+  (rb_cairo_surface_to_ruby_object_with_destroy(surface))
 
 cairo_t              *rb_cairo_context_from_ruby_object      (VALUE obj);
 VALUE                 rb_cairo_context_to_ruby_object        (cairo_t *cr);
@@ -196,6 +191,8 @@ VALUE                 rb_cairo_glyph_to_ruby_object          (cairo_glyph_t *gly
 
 cairo_surface_t      *rb_cairo_surface_from_ruby_object      (VALUE obj);
 VALUE                 rb_cairo_surface_to_ruby_object        (cairo_surface_t *surface);
+VALUE                 rb_cairo_surface_to_ruby_object_with_destroy
+                                                             (cairo_surface_t *surface);
 
 
 #define RVAL2CROPERATOR(obj)      (rb_cairo_operator_from_ruby_object(obj))
@@ -213,9 +210,14 @@ VALUE                 rb_cairo_surface_to_ruby_object        (cairo_surface_t *s
 #define RVAL2CRFORMAT(obj)        (rb_cairo_format_from_ruby_object(obj))
 #define RVAL2CREXTEND(obj)        (rb_cairo_extend_from_ruby_object(obj))
 #define RVAL2CRFILTER(obj)        (rb_cairo_filter_from_ruby_object(obj))
-#if CAIRO_HAS_SVG_SURFACE
+#ifdef CAIRO_HAS_SVG_SURFACE
 #define RVAL2CRSVGVERSION(obj)    (rb_cairo_svg_version_from_ruby_object(obj))
 #endif
+#ifdef CAIRO_HAS_PS_SURFACE
+#  if CAIRO_CHECK_VERSION(1, 5, 2)
+#define RVAL2CRPSLEVEL(obj)       (rb_cairo_ps_level_from_ruby_object(obj))
+#  endif
+#endif
 
 cairo_operator_t       rb_cairo_operator_from_ruby_object       (VALUE obj);
 cairo_antialias_t      rb_cairo_antialias_from_ruby_object      (VALUE obj);
@@ -232,9 +234,14 @@ cairo_content_t        rb_cairo_content_from_ruby_object        (VALUE obj);
 cairo_format_t         rb_cairo_format_from_ruby_object         (VALUE obj);
 cairo_extend_t         rb_cairo_extend_from_ruby_object         (VALUE obj);
 cairo_filter_t         rb_cairo_filter_from_ruby_object         (VALUE obj);
-#if CAIRO_HAS_SVG_SURFACE
+#ifdef CAIRO_HAS_SVG_SURFACE
 cairo_svg_version_t    rb_cairo_svg_version_from_ruby_object    (VALUE obj);
 #endif
+#ifdef CAIRO_HAS_PS_SURFACE
+#  if CAIRO_CHECK_VERSION(1, 5, 2)
+cairo_ps_level_t       rb_cairo_ps_level_from_ruby_object       (VALUE obj);
+#  endif
+#endif
 
 void rb_cairo_check_status (cairo_status_t status);
 
