@@ -3,7 +3,7 @@
  * Ruby Cairo Binding
  *
  * $Author: kou $
- * $Date: 2007-12-29 11:42:26 $
+ * $Date: 2008-06-12 10:59:54 $
  *
  * Copyright 2005 Øyvind Kolås <pippin@freedesktop.org>
  * Copyright 2004-2005 MenTaLguY <mental@rydia.com>
@@ -22,12 +22,12 @@ static ID cr_id_plus, cr_id_minus, cr_id_multi, cr_id_div;
 
 #define _SELF  (RVAL2CRCONTEXT(self))
 
+static VALUE cr_get_current_point (VALUE self);
+
 #if CAIRO_CHECK_VERSION(1, 3, 0)
 static VALUE rb_cCairo_Rectangle;
 static ID at_x, at_y, at_width, at_height;
 
-static VALUE cr_get_current_point (VALUE self);
-
 static VALUE
 cr_rectangle_initialize (VALUE self, VALUE x, VALUE y,
                          VALUE width, VALUE height)
@@ -97,7 +97,7 @@ cr_initialize (VALUE self, VALUE target)
   cr = cairo_create (RVAL2CRSURFACE (target));
   cr_check_status (cr);
   rb_ivar_set (self, cr_id_surface, target);
-  DATA_PTR(self) = cr;
+  DATA_PTR (self) = cr;
   return Qnil;
 }
 
@@ -211,7 +211,7 @@ cr_set_source_rgb (int argc, VALUE *argv, VALUE self)
   if (n == 1 && rb_cairo__is_kind_of (red, rb_cArray))
     {
       VALUE ary = red;
-      n = RARRAY (ary)->len;
+      n = RARRAY_LEN (ary);
       red = rb_ary_entry (ary, 0);
       green = rb_ary_entry (ary, 1);
       blue = rb_ary_entry (ary, 2);
@@ -248,7 +248,7 @@ cr_set_source_rgba (int argc, VALUE *argv, VALUE self)
   if (n == 1 && rb_cairo__is_kind_of (red, rb_cArray))
     {
       VALUE ary = red;
-      n = RARRAY (ary)->len;
+      n = RARRAY_LEN (ary);
       red = rb_ary_entry (ary, 0);
       green = rb_ary_entry (ary, 1);
       blue = rb_ary_entry (ary, 2);
@@ -413,7 +413,7 @@ cr_set_dash (int argc, VALUE *argv, VALUE self)
       values[0] = NUM2DBL (dash_array);
       cairo_set_dash (_SELF, values, 1, offset);
     }
-  else if (NIL_P (dash_array) || RARRAY (dash_array)->len == 0)
+  else if (NIL_P (dash_array) || RARRAY_LEN (dash_array) == 0)
     {
       cairo_set_dash (_SELF, NULL, 0, offset);
     }
@@ -421,7 +421,7 @@ cr_set_dash (int argc, VALUE *argv, VALUE self)
     {
       int i, length;
       double *values;
-      length = RARRAY (dash_array)->len;
+      length = RARRAY_LEN (dash_array);
       values = ALLOCA_N (double, length);
       if (!values)
         {
@@ -429,7 +429,7 @@ cr_set_dash (int argc, VALUE *argv, VALUE self)
         }
       for (i = 0; i < length; i++)
         {
-          values[i] = NUM2DBL (RARRAY (dash_array)->ptr[i]);
+          values[i] = NUM2DBL (RARRAY_PTR (dash_array)[i]);
         }
       cairo_set_dash (_SELF, values, length, offset);
     }
@@ -588,8 +588,8 @@ cr_quadratic_curve_to (VALUE self, VALUE x1, VALUE y1, VALUE x2, VALUE y2)
   VALUE current_point, x0, y0, cx1, cy1, cx2, cy2;
 
   current_point = cr_get_current_point (self);
-  x0 = RARRAY (current_point)->ptr[0];
-  y0 = RARRAY (current_point)->ptr[1];
+  x0 = RARRAY_PTR (current_point)[0];
+  y0 = RARRAY_PTR (current_point)[1];
 
   /* cx1 = x0 + 2 * ((x1 - x0) / 3.0) */
   cx1 = rb_funcall (x0, cr_id_plus, 1,
@@ -689,8 +689,8 @@ cr_rel_quadratic_curve_to (VALUE self, VALUE dx1, VALUE dy1,
   VALUE current_point, x0, y0;
 
   current_point = cr_get_current_point (self);
-  x0 = RARRAY (current_point)->ptr[0];
-  y0 = RARRAY (current_point)->ptr[1];
+  x0 = RARRAY_PTR (current_point)[0];
+  y0 = RARRAY_PTR (current_point)[1];
   return cr_quadratic_curve_to (self,
                                 rb_funcall (dx1, cr_id_plus, 1, x0),
                                 rb_funcall (dy1, cr_id_plus, 1, y0),
@@ -738,6 +738,19 @@ cr_close_path (VALUE self)
   return self;
 }
 
+#if CAIRO_CHECK_VERSION(1, 5, 8)
+static VALUE
+cr_path_extents (VALUE self)
+{
+  double x1, y1, x2, y2;
+  cairo_path_extents (_SELF, &x1, &y1, &x2, &y2);
+  cr_check_status (_SELF);
+  return rb_ary_new3 (4,
+                      rb_float_new(x1), rb_float_new(y1),
+                      rb_float_new(x2), rb_float_new(y2));
+}
+#endif
+
 /* Painting functions */
 static VALUE
 cr_paint (VALUE self)
@@ -1216,9 +1229,17 @@ cr_get_tolerance (VALUE self)
 static VALUE
 cr_get_antialias(VALUE self)
 {
-  return INT2NUM (cairo_get_antialias(_SELF));
+  return INT2NUM (cairo_get_antialias (_SELF));
 }
 
+#if CAIRO_CHECK_VERSION(1, 5, 10)
+static VALUE
+cr_has_current_point(VALUE self)
+{
+  return RTEST (cairo_has_current_point (_SELF));
+}
+#endif
+
 static VALUE
 cr_get_current_point (VALUE self)
 {
@@ -1438,6 +1459,9 @@ Init_cairo_context (void)
                     cr_rel_curve_to_generic, -1);
   rb_define_method (rb_cCairo_Context, "rectangle", cr_rectangle, 4);
   rb_define_method (rb_cCairo_Context, "close_path", cr_close_path, 0);
+#if CAIRO_CHECK_VERSION(1, 5, 8)
+  rb_define_method (rb_cCairo_Context, "path_extents", cr_path_extents, 0);
+#endif
 
   /* Painting functions */
   rb_define_method (rb_cCairo_Context, "paint", cr_paint_generic, -1);
@@ -1494,6 +1518,12 @@ Init_cairo_context (void)
   rb_define_method (rb_cCairo_Context, "source", cr_get_source, 0);
   rb_define_method (rb_cCairo_Context, "tolerance", cr_get_tolerance, 0);
   rb_define_method (rb_cCairo_Context, "antialias", cr_get_antialias, 0);
+#if CAIRO_CHECK_VERSION(1, 5, 10)
+  rb_define_method (rb_cCairo_Context, "have_current_point?",
+                    cr_has_current_point, 0);
+  rb_define_alias (rb_cCairo_Context,
+                   "has_current_point?", "have_current_point?");
+#endif
   rb_define_method (rb_cCairo_Context, "current_point",
                     cr_get_current_point, 0);
   rb_define_method (rb_cCairo_Context, "fill_rule", cr_get_fill_rule, 0);
