@@ -3,7 +3,7 @@
  * Ruby Cairo Binding
  *
  * $Author: kou $
- * $Date: 2007-03-06 12:17:34 $
+ * $Date: 2008-02-21 13:18:10 $
  *
  * Copyright 2005 Øyvind Kolås <pippin@freedesktop.org>
  * Copyright 2004-2005 MenTaLguY <mental@rydia.com>
@@ -37,6 +37,10 @@ static VALUE rb_eCairo_InvalidDscCommentError;
 static VALUE rb_eCairo_InvalidIndexError;
 static VALUE rb_eCairo_ClipNotRepresentableError;
 #endif
+#if CAIRO_CHECK_VERSION(1, 5, 6)
+static VALUE rb_eCairo_TempFileError;
+static VALUE rb_eCairo_InvalidStrideError;
+#endif
 
 void
 rb_cairo_check_status (cairo_status_t status)
@@ -114,6 +118,14 @@ rb_cairo_check_status (cairo_status_t status)
     case CAIRO_STATUS_CLIP_NOT_REPRESENTABLE:
       rb_raise (rb_eCairo_ClipNotRepresentableError, string);
       break;
+#endif
+#if CAIRO_CHECK_VERSION(1, 5, 6)
+    case CAIRO_STATUS_TEMP_FILE_ERROR:
+      rb_raise (rb_eCairo_TempFileError, string);
+      break;
+    case CAIRO_STATUS_INVALID_STRIDE:
+      rb_raise (rb_eCairo_InvalidStringError, string);
+      break;
 #endif
     }
 }
@@ -189,4 +201,14 @@ Init_cairo_exception ()
     rb_define_class_under (rb_mCairo, "ClipNotRepresentableError",
                            rb_eCairo_Error);
 #endif
+
+#if CAIRO_CHECK_VERSION(1, 5, 6)
+  rb_eCairo_TempFileError =
+    rb_define_class_under (rb_mCairo, "TempFileError",
+                           rb_eCairo_Error);
+
+  rb_eCairo_InvalidStrideError =
+        rb_define_class_under (rb_mCairo, "InvalidStrideError",
+                               rb_eArgError);
+#endif
 }
